django-auction
==============

.. image:: https://travis-ci.org/littlepea/django-auction.png?branch=develop
    :target: http://travis-ci.org/littlepea/django-auction

A Django auction system.

Contributing
------------

Pick an `issue <https://github.com/littlepea/django-auction/issues>`_ and `fork <https://github.com/littlepea/django-auction/fork>`_ at will ;)
